@@ -4,7 +4,7 @@ use strict;
 use warnings;
 
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 
 1;
@@ -105,10 +105,14 @@ Module::Cloud
 
 Module::Install::StandardTests
 
+Module::Install::Template
+
 Net::IP::Match
 
 Number::Rangify
 
+Pod::Generated
+
 Regexp::Common::AT::NICAT
 
 Scalar::Properties
@@ -133,6 +137,12 @@ Test::Compile
 
 Test::Distribution
 
+Text::Pipe
+
+Text::Pipe::HTML
+
+Text::Pipe::Encoding
+
 Text::UpsideDown
 
 Tie::Scalar::Timeout
